#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 
# Copyright 2008 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
   HQL plugin

   Plugin read by omero.cli.Cli during initialization. The method(s)
   defined here will be added to the Cli class for later use.
"""
from __future__ import division

from builtins import str
from builtins import range
from past.utils import old_div
from omero.cli import BaseControl, CLI
import time
import sys

HELP = """Executes an HQL statement with the given parameters

If no query is given, then a shell is opened which will run any entered query
with the current parameters.
"""

BLACKLISTED_KEYS = ["_id", "_loaded", "_bytes"]
WHITELISTED_VALUES = [0, False]


class HqlControl(BaseControl):

    def _configure(self, parser):
        parser.set_defaults(func=self.__call__)
        parser.add_argument("query", nargs="?", help="Single query to run")
        parser.add_argument(
            "--admin", help="Run an admin query (deprecated; use 'all')",
            default=False, action="store_true")
        parser.add_argument(
            "--all", help="Perform query on all groups", default=False,
            action="store_true", dest="admin")
        parser.add_argument(
            "--ids-only",
            action="store_true",
            help="Show only the ids of returned objects")
        parser.add_limit_arguments()
        parser.add_style_argument()
        parser.add_login_arguments()
        self.add_error("NO_QUIET", 67,
                       "Can't ask for query with --quiet option")
        self.add_error("NOT_ADMIN", 53,
                       ("SecurityViolation: Current user is not an"
                        " admin and cannot use '--admin'"))
        self.add_error("BAD_QUERY", 52, "Bad query: %s")

    def __call__(self, args):
        if args.query:
            self.hql(args)
        else:
            if self.ctx.isquiet:
                self.raise_error("NO_QUIET")
            while True:
                args.query = self.ctx.input("Enter query:")
                if not args.query:
                    break
                if not self.hql(args, loop=True):
                    break

    def hql(self, args, loop=False):
        from omero_sys_ParametersI import ParametersI

        ice_map = dict()
        if args.admin:
            ice_map["omero.group"] = "-1"

        c = self.ctx.conn(args)
        q = c.sf.getQueryService()
        p = ParametersI()
        p.page(args.offset, args.limit)
        rv = self.project(q, args.query, p, ice_map)
        has_details = self.display(rv, style=args.style,
                                   idsonly=args.ids_only)
        if self.ctx.isquiet or not sys.stdout.isatty():
            return

        input = """
To see details for object, enter line number.
To move ahead one page, enter 'p'
To re-display list, enter 'r'.
To quit, enter 'q' or just enter.
"""
        if loop:
            input = input + """To run another query, press enter\n"""

        while True:
            id = self.ctx.input(input)
            id = id.lower()

            # Exit loop
            if not id:
                return True
            if id.startswith("q"):
                return False

            # Stay in loop
            if id.startswith("p"):
                p.page(p.getOffset().val + p.getLimit().val, p.getLimit())
                self.ctx.dbg("\nCurrent page: offset=%s, limit=%s\n" %
                             (p.theFilter.offset.val, p.theFilter.limit.val))
                rv = self.project(q, args.query, p, ice_map)
                self.display(rv, style=args.style, idsonly=args.ids_only)
            elif id.startswith("r"):
                self.display(rv, style=args.style, idsonly=args.ids_only)
            else:
                try:
                    id = int(id)
                    obj = rv[id]
                    if id not in has_details:
                        self.ctx.out("No details available: %s" % id)
                        continue
                    else:
                        # Unwrap the object_list from IQuery.projection
                        obj = obj[0].val
                except:
                    self.ctx.out("Invalid choice: %s" % id)
                    continue
                keys = sorted(obj.__dict__)
                keys.remove("_id")
                keys.remove("_details")
                self.ctx.out("id = %s" % obj.id.val)
                for key in keys:
                    value = self.unwrap(obj.__dict__[key])
                    if isinstance(value, str):
                        value = "'%s'" % value
                    if key.startswith("_"):
                        key = key[1:]
                    self.ctx.out("%s = %s" % (key, value))
            continue

    def display(self, rv, cols=None, style=None, idsonly=False):
        import omero.all
        import omero.rtypes
        from omero.util.text import TableBuilder

        has_details = []
        tb = TableBuilder("#")
        if style:
            tb.set_style(style)
        for idx, object_list in enumerate(rv):
            klass = "Null"
            id = ""
            values = {}
            # Handling for simple lookup
            if not idsonly and len(object_list) == 1 and \
                    isinstance(object_list[0], omero.rtypes.RObjectI):
                has_details.append(idx)
                o = object_list[0].val
                if o:
                    tb.cols(["Class", "Id"])
                    klass = o.__class__.__name__
                    id = o.id.val
                    for k, v in list(o.__dict__.items()):
                        values[k] = self.unwrap(v)
                    values = self.filter(values)
                    tb.cols(list(values.keys()))
                tb.row(idx, klass, id, **values)
            # Handling for true projections
            else:
                indices = list(range(1, len(object_list) + 1))
                if cols is not None:
                    tb.cols(cols)
                else:
                    tb.cols(["Col%s" % x for x in indices])
                values = tuple([self.unwrap(x) for x in object_list])
                tb.row(idx, *values)
        self.ctx.out(str(tb.build()))
        return has_details

    def unwrap(self, object, cache=None):

        if cache is None:
            cache = {}
        elif object in cache:
            return cache[id(object)]

        from omero.rtypes import unwrap
        from omero.model import IObject
        from omero.model import Details
        from omero.rtypes import RTimeI
        # if isinstance(object, list):
        #    return [self.unwrap(x, cache) for x in object]
        # elif isinstance(object, RObject):
        #    return self.unwrap(object.val, cache)
        unwrapped = unwrap(object, cache)
        if isinstance(unwrapped, IObject):
            rv = "%s:%s" % (unwrapped.__class__.__name__, unwrapped.id.val)
        elif isinstance(object, RTimeI):
            rv = time.ctime(old_div(unwrapped,1000.0))
        elif isinstance(object, Details):
            owner = None
            group = None
            if unwrapped.owner is not None:
                owner = unwrapped.owner.id.val
            if unwrapped.group is not None:
                group = unwrapped.group.id.val
            rv = "owner=%s;group=%s" % (owner, group)
        else:
            rv = unwrapped

        cache[id(object)] = rv
        return rv

    def filter(self, values):
        values = dict(values)

        # Filter out blacklisted items
        blacklisted_keys = [x for x in values if x in BLACKLISTED_KEYS]
        for key in blacklisted_keys:
            values.pop(key)

        # Filter out _Loaded keys
        loaded_keys = [x for x in values if x.startswith("_")
                       and x.endswith("Loaded")]
        for key in loaded_keys:
            values.pop(key)

        # Filter out details
        if "owner=None;group=None" == values.get("_details"):
            values.pop("_details")

        # Filter out multi-valued and empty-valued items
        multi_valued = sorted([k for k in values
                               if isinstance(values[k], list)])
        empty_valued = sorted([
            k for k in values if not values[k] and values[k] not in
            WHITELISTED_VALUES])

        for x in multi_valued + empty_valued:
            if x in values:
                values.pop(x)

        rv = dict()
        for k, v in list(values.items()):
            if k.startswith("_"):
                rv[k[1:]] = v
            else:
                rv[k] = v
        return rv

    def project(self, querySvc, queryStr, params, ice_map):
        import omero
        try:
            rv = querySvc.projection(queryStr, params, ice_map)
            self.ctx.set("last.hql.rv", rv)
            return rv
        except omero.SecurityViolation as sv:
            if "omero.group" in ice_map:
                self.raise_error("NOT_ADMIN")
            else:
                self.ctx.die(54, "SecurityViolation: %s" % sv)
        except omero.QueryException as qe:
            self.ctx.set("last.hql.rv", [])
            self.raise_error("BAD_QUERY", qe.message)

try:
    register("hql", HqlControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("hql", HqlControl, HELP)
        cli.invoke(sys.argv[1:])



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `PlateAcquisition.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Plate' not in _M_omero.model.__dict__:
    _M_omero.model._t_Plate = IcePy.declareClass('::omero::model::Plate')
    _M_omero.model._t_PlatePrx = IcePy.declareProxy('::omero::model::Plate')

if 'WellSample' not in _M_omero.model.__dict__:
    _M_omero.model._t_WellSample = IcePy.declareClass('::omero::model::WellSample')
    _M_omero.model._t_WellSamplePrx = IcePy.declareProxy('::omero::model::WellSample')

if 'PlateAcquisitionAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisitionAnnotationLink = IcePy.declareClass('::omero::model::PlateAcquisitionAnnotationLink')
    _M_omero.model._t_PlateAcquisitionAnnotationLinkPrx = IcePy.declareProxy('::omero::model::PlateAcquisitionAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_PlateAcquisitionWellSampleSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisitionWellSampleSeq = IcePy.defineSequence('::omero::model::PlateAcquisitionWellSampleSeq', (), _M_omero.model._t_WellSample)

if '_t_PlateAcquisitionAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq = IcePy.defineSequence('::omero::model::PlateAcquisitionAnnotationLinksSeq', (), _M_omero.model._t_PlateAcquisitionAnnotationLink)

if '_t_PlateAcquisitionLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisitionLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::PlateAcquisitionLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'PlateAcquisition' not in _M_omero.model.__dict__:
    _M_omero.model.PlateAcquisition = Ice.createTempClass()
    class PlateAcquisition(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _name=None, _startTime=None, _endTime=None, _maximumFieldCount=None, _plate=None, _wellSampleSeq=None, _wellSampleLoaded=False, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _description=None):
            if Ice.getType(self) == _M_omero.model.PlateAcquisition:
                raise RuntimeError('omero.model.PlateAcquisition is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._name = _name
            self._startTime = _startTime
            self._endTime = _endTime
            self._maximumFieldCount = _maximumFieldCount
            self._plate = _plate
            self._wellSampleSeq = _wellSampleSeq
            self._wellSampleLoaded = _wellSampleLoaded
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::PlateAcquisition')

        def ice_id(self, current=None):
            return '::omero::model::PlateAcquisition'

        def ice_staticId():
            return '::omero::model::PlateAcquisition'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getStartTime(self, current=None):
            pass

        def setStartTime(self, theStartTime, current=None):
            pass

        def getEndTime(self, current=None):
            pass

        def setEndTime(self, theEndTime, current=None):
            pass

        def getMaximumFieldCount(self, current=None):
            pass

        def setMaximumFieldCount(self, theMaximumFieldCount, current=None):
            pass

        def getPlate(self, current=None):
            pass

        def setPlate(self, thePlate, current=None):
            pass

        def unloadWellSample(self, current=None):
            pass

        def sizeOfWellSample(self, current=None):
            pass

        def copyWellSample(self, current=None):
            pass

        def addWellSample(self, target, current=None):
            pass

        def addAllWellSampleSet(self, targets, current=None):
            pass

        def removeWellSample(self, theTarget, current=None):
            pass

        def removeAllWellSampleSet(self, targets, current=None):
            pass

        def clearWellSample(self, current=None):
            pass

        def reloadWellSample(self, toCopy, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addPlateAcquisitionAnnotationLink(self, target, current=None):
            pass

        def addAllPlateAcquisitionAnnotationLinkSet(self, targets, current=None):
            pass

        def removePlateAcquisitionAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllPlateAcquisitionAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addPlateAcquisitionAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findPlateAcquisitionAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removePlateAcquisitionAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_PlateAcquisition)

        __repr__ = __str__

    _M_omero.model.PlateAcquisitionPrx = Ice.createTempClass()
    class PlateAcquisitionPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.PlateAcquisition._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.PlateAcquisition._op_setVersion.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.PlateAcquisition._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.PlateAcquisition._op_setName.end(self, _r)

        def getStartTime(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getStartTime.invoke(self, ((), _ctx))

        def begin_getStartTime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getStartTime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStartTime(self, _r):
            return _M_omero.model.PlateAcquisition._op_getStartTime.end(self, _r)

        def setStartTime(self, theStartTime, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setStartTime.invoke(self, ((theStartTime, ), _ctx))

        def begin_setStartTime(self, theStartTime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setStartTime.begin(self, ((theStartTime, ), _response, _ex, _sent, _ctx))

        def end_setStartTime(self, _r):
            return _M_omero.model.PlateAcquisition._op_setStartTime.end(self, _r)

        def getEndTime(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getEndTime.invoke(self, ((), _ctx))

        def begin_getEndTime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getEndTime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEndTime(self, _r):
            return _M_omero.model.PlateAcquisition._op_getEndTime.end(self, _r)

        def setEndTime(self, theEndTime, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setEndTime.invoke(self, ((theEndTime, ), _ctx))

        def begin_setEndTime(self, theEndTime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setEndTime.begin(self, ((theEndTime, ), _response, _ex, _sent, _ctx))

        def end_setEndTime(self, _r):
            return _M_omero.model.PlateAcquisition._op_setEndTime.end(self, _r)

        def getMaximumFieldCount(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getMaximumFieldCount.invoke(self, ((), _ctx))

        def begin_getMaximumFieldCount(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getMaximumFieldCount.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMaximumFieldCount(self, _r):
            return _M_omero.model.PlateAcquisition._op_getMaximumFieldCount.end(self, _r)

        def setMaximumFieldCount(self, theMaximumFieldCount, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setMaximumFieldCount.invoke(self, ((theMaximumFieldCount, ), _ctx))

        def begin_setMaximumFieldCount(self, theMaximumFieldCount, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setMaximumFieldCount.begin(self, ((theMaximumFieldCount, ), _response, _ex, _sent, _ctx))

        def end_setMaximumFieldCount(self, _r):
            return _M_omero.model.PlateAcquisition._op_setMaximumFieldCount.end(self, _r)

        def getPlate(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getPlate.invoke(self, ((), _ctx))

        def begin_getPlate(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getPlate.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPlate(self, _r):
            return _M_omero.model.PlateAcquisition._op_getPlate.end(self, _r)

        def setPlate(self, thePlate, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setPlate.invoke(self, ((thePlate, ), _ctx))

        def begin_setPlate(self, thePlate, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setPlate.begin(self, ((thePlate, ), _response, _ex, _sent, _ctx))

        def end_setPlate(self, _r):
            return _M_omero.model.PlateAcquisition._op_setPlate.end(self, _r)

        def unloadWellSample(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unloadWellSample.invoke(self, ((), _ctx))

        def begin_unloadWellSample(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unloadWellSample.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_unloadWellSample.end(self, _r)

        def sizeOfWellSample(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_sizeOfWellSample.invoke(self, ((), _ctx))

        def begin_sizeOfWellSample(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_sizeOfWellSample.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_sizeOfWellSample.end(self, _r)

        def copyWellSample(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_copyWellSample.invoke(self, ((), _ctx))

        def begin_copyWellSample(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_copyWellSample.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_copyWellSample.end(self, _r)

        def addWellSample(self, target, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addWellSample.invoke(self, ((target, ), _ctx))

        def begin_addWellSample(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addWellSample.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_addWellSample.end(self, _r)

        def addAllWellSampleSet(self, targets, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addAllWellSampleSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllWellSampleSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addAllWellSampleSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllWellSampleSet(self, _r):
            return _M_omero.model.PlateAcquisition._op_addAllWellSampleSet.end(self, _r)

        def removeWellSample(self, theTarget, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeWellSample.invoke(self, ((theTarget, ), _ctx))

        def begin_removeWellSample(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeWellSample.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_removeWellSample.end(self, _r)

        def removeAllWellSampleSet(self, targets, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeAllWellSampleSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllWellSampleSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeAllWellSampleSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllWellSampleSet(self, _r):
            return _M_omero.model.PlateAcquisition._op_removeAllWellSampleSet.end(self, _r)

        def clearWellSample(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_clearWellSample.invoke(self, ((), _ctx))

        def begin_clearWellSample(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_clearWellSample.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_clearWellSample.end(self, _r)

        def reloadWellSample(self, toCopy, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_reloadWellSample.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadWellSample(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_reloadWellSample.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadWellSample(self, _r):
            return _M_omero.model.PlateAcquisition._op_reloadWellSample.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.PlateAcquisition._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.PlateAcquisition._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.PlateAcquisition._op_copyAnnotationLinks.end(self, _r)

        def addPlateAcquisitionAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addPlateAcquisitionAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPlateAcquisitionAnnotationLink(self, _r):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLink.end(self, _r)

        def addAllPlateAcquisitionAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addAllPlateAcquisitionAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPlateAcquisitionAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addAllPlateAcquisitionAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPlateAcquisitionAnnotationLinkSet(self, _r):
            return _M_omero.model.PlateAcquisition._op_addAllPlateAcquisitionAnnotationLinkSet.end(self, _r)

        def removePlateAcquisitionAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removePlateAcquisitionAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePlateAcquisitionAnnotationLink(self, _r):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLink.end(self, _r)

        def removeAllPlateAcquisitionAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeAllPlateAcquisitionAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPlateAcquisitionAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removeAllPlateAcquisitionAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPlateAcquisitionAnnotationLinkSet(self, _r):
            return _M_omero.model.PlateAcquisition._op_removeAllPlateAcquisitionAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.PlateAcquisition._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.PlateAcquisition._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.PlateAcquisition._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.PlateAcquisition._op_linkAnnotation.end(self, _r)

        def addPlateAcquisitionAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addPlateAcquisitionAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addPlateAcquisitionAnnotationLinkToBoth(self, _r):
            return _M_omero.model.PlateAcquisition._op_addPlateAcquisitionAnnotationLinkToBoth.end(self, _r)

        def findPlateAcquisitionAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_findPlateAcquisitionAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findPlateAcquisitionAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_findPlateAcquisitionAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findPlateAcquisitionAnnotationLink(self, _r):
            return _M_omero.model.PlateAcquisition._op_findPlateAcquisitionAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.PlateAcquisition._op_unlinkAnnotation.end(self, _r)

        def removePlateAcquisitionAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removePlateAcquisitionAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removePlateAcquisitionAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.PlateAcquisition._op_removePlateAcquisitionAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.PlateAcquisition._op_linkedAnnotationList.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.PlateAcquisition._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlateAcquisition._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.PlateAcquisition._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PlateAcquisitionPrx.ice_checkedCast(proxy, '::omero::model::PlateAcquisition', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PlateAcquisitionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::PlateAcquisition'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PlateAcquisitionPrx = IcePy.defineProxy('::omero::model::PlateAcquisition', PlateAcquisitionPrx)

    _M_omero.model._t_PlateAcquisition = IcePy.declareClass('::omero::model::PlateAcquisition')

    _M_omero.model._t_PlateAcquisition = IcePy.defineClass('::omero::model::PlateAcquisition', PlateAcquisition, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_startTime', (), _M_omero._t_RTime, False, 0),
        ('_endTime', (), _M_omero._t_RTime, False, 0),
        ('_maximumFieldCount', (), _M_omero._t_RInt, False, 0),
        ('_plate', (), _M_omero.model._t_Plate, False, 0),
        ('_wellSampleSeq', (), _M_omero.model._t_PlateAcquisitionWellSampleSeq, False, 0),
        ('_wellSampleLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    PlateAcquisition._ice_type = _M_omero.model._t_PlateAcquisition

    PlateAcquisition._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlateAcquisition._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlateAcquisition._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    PlateAcquisition._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    PlateAcquisition._op_getStartTime = IcePy.Operation('getStartTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    PlateAcquisition._op_setStartTime = IcePy.Operation('setStartTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    PlateAcquisition._op_getEndTime = IcePy.Operation('getEndTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    PlateAcquisition._op_setEndTime = IcePy.Operation('setEndTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    PlateAcquisition._op_getMaximumFieldCount = IcePy.Operation('getMaximumFieldCount', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlateAcquisition._op_setMaximumFieldCount = IcePy.Operation('setMaximumFieldCount', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlateAcquisition._op_getPlate = IcePy.Operation('getPlate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Plate, False, 0), ())
    PlateAcquisition._op_setPlate = IcePy.Operation('setPlate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Plate, False, 0),), (), None, ())
    PlateAcquisition._op_unloadWellSample = IcePy.Operation('unloadWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlateAcquisition._op_sizeOfWellSample = IcePy.Operation('sizeOfWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    PlateAcquisition._op_copyWellSample = IcePy.Operation('copyWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateAcquisitionWellSampleSeq, False, 0), ())
    PlateAcquisition._op_addWellSample = IcePy.Operation('addWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellSample, False, 0),), (), None, ())
    PlateAcquisition._op_addAllWellSampleSet = IcePy.Operation('addAllWellSampleSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionWellSampleSeq, False, 0),), (), None, ())
    PlateAcquisition._op_removeWellSample = IcePy.Operation('removeWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellSample, False, 0),), (), None, ())
    PlateAcquisition._op_removeAllWellSampleSet = IcePy.Operation('removeAllWellSampleSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionWellSampleSeq, False, 0),), (), None, ())
    PlateAcquisition._op_clearWellSample = IcePy.Operation('clearWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlateAcquisition._op_reloadWellSample = IcePy.Operation('reloadWellSample', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisition, False, 0),), (), None, ())
    PlateAcquisition._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlateAcquisition._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    PlateAcquisition._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq, False, 0), ())
    PlateAcquisition._op_addPlateAcquisitionAnnotationLink = IcePy.Operation('addPlateAcquisitionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLink, False, 0),), (), None, ())
    PlateAcquisition._op_addAllPlateAcquisitionAnnotationLinkSet = IcePy.Operation('addAllPlateAcquisitionAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq, False, 0),), (), None, ())
    PlateAcquisition._op_removePlateAcquisitionAnnotationLink = IcePy.Operation('removePlateAcquisitionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLink, False, 0),), (), None, ())
    PlateAcquisition._op_removeAllPlateAcquisitionAnnotationLinkSet = IcePy.Operation('removeAllPlateAcquisitionAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq, False, 0),), (), None, ())
    PlateAcquisition._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlateAcquisition._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisition, False, 0),), (), None, ())
    PlateAcquisition._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    PlateAcquisition._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlateAcquisitionAnnotationLink, False, 0), ())
    PlateAcquisition._op_addPlateAcquisitionAnnotationLinkToBoth = IcePy.Operation('addPlateAcquisitionAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    PlateAcquisition._op_findPlateAcquisitionAnnotationLink = IcePy.Operation('findPlateAcquisitionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlateAcquisitionAnnotationLinksSeq, False, 0), ())
    PlateAcquisition._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    PlateAcquisition._op_removePlateAcquisitionAnnotationLinkFromBoth = IcePy.Operation('removePlateAcquisitionAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisitionAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    PlateAcquisition._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateAcquisitionLinkedAnnotationSeq, False, 0), ())
    PlateAcquisition._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    PlateAcquisition._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.PlateAcquisition = PlateAcquisition
    del PlateAcquisition

    _M_omero.model.PlateAcquisitionPrx = PlateAcquisitionPrx
    del PlateAcquisitionPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `FS.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_Collections_ice
import omero_cmd_API_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.cmd
_M_omero.cmd = Ice.openModule('omero.cmd')

# Start of module omero
__name__ = 'omero'

# Start of module omero.cmd
__name__ = 'omero.cmd'

if 'FindPyramids' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FindPyramids = Ice.createTempClass()
    class FindPyramids(_M_omero.cmd.Request):
        """
        Requests all pyramids files. A FindPyramidsResponse
        will be returned under normal conditions, otherwise a ERR
        will be returned.
        Members:
        littleEndian -- Retrieves the pyramids with little endian true or false.
        If unset, both will be retrieved.
        importedAfter -- Retrieves the pyramids created after a specified time if set.
        checkEmptyFile -- Retrieves the pyramids of length 0 if true
        limit -- The maximum number of files to find. No limit will be applied
        if set to 0 or to a negative value.
        """
        def __init__(self, littleEndian=None, importedAfter=None, checkEmptyFile=False, limit=0):
            _M_omero.cmd.Request.__init__(self)
            self.littleEndian = littleEndian
            self.importedAfter = importedAfter
            self.checkEmptyFile = checkEmptyFile
            self.limit = limit

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FindPyramids', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::FindPyramids'

        def ice_staticId():
            return '::omero::cmd::FindPyramids'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FindPyramids)

        __repr__ = __str__

    _M_omero.cmd.FindPyramidsPrx = Ice.createTempClass()
    class FindPyramidsPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FindPyramidsPrx.ice_checkedCast(proxy, '::omero::cmd::FindPyramids', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FindPyramidsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FindPyramids'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FindPyramidsPrx = IcePy.defineProxy('::omero::cmd::FindPyramids', FindPyramidsPrx)

    _M_omero.cmd._t_FindPyramids = IcePy.declareClass('::omero::cmd::FindPyramids')

    _M_omero.cmd._t_FindPyramids = IcePy.defineClass('::omero::cmd::FindPyramids', FindPyramids, -1, (), False, False, _M_omero.cmd._t_Request, (), (
        ('littleEndian', (), _M_omero._t_RBool, False, 0),
        ('importedAfter', (), _M_omero._t_RTime, False, 0),
        ('checkEmptyFile', (), IcePy._t_bool, False, 0),
        ('limit', (), IcePy._t_long, False, 0)
    ))
    FindPyramids._ice_type = _M_omero.cmd._t_FindPyramids

    _M_omero.cmd.FindPyramids = FindPyramids
    del FindPyramids

    _M_omero.cmd.FindPyramidsPrx = FindPyramidsPrx
    del FindPyramidsPrx

if 'FindPyramidsResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.FindPyramidsResponse = Ice.createTempClass()
    class FindPyramidsResponse(_M_omero.cmd.OK):
        """
        Returns the image Ids corresponding to the pyramid files.
        A FindPyramidsResponse
        will be returned under normal conditions, otherwise a ERR
        will be returned.
        Members:
        pyramidFiles -- The image IDs corresponding to the pyramid
        """
        def __init__(self, pyramidFiles=None):
            _M_omero.cmd.OK.__init__(self)
            self.pyramidFiles = pyramidFiles

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::FindPyramidsResponse', '::omero::cmd::OK', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::FindPyramidsResponse'

        def ice_staticId():
            return '::omero::cmd::FindPyramidsResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_FindPyramidsResponse)

        __repr__ = __str__

    _M_omero.cmd.FindPyramidsResponsePrx = Ice.createTempClass()
    class FindPyramidsResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.FindPyramidsResponsePrx.ice_checkedCast(proxy, '::omero::cmd::FindPyramidsResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.FindPyramidsResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::FindPyramidsResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_FindPyramidsResponsePrx = IcePy.defineProxy('::omero::cmd::FindPyramidsResponse', FindPyramidsResponsePrx)

    _M_omero.cmd._t_FindPyramidsResponse = IcePy.defineClass('::omero::cmd::FindPyramidsResponse', FindPyramidsResponse, -1, (), False, False, _M_omero.cmd._t_OK, (), (('pyramidFiles', (), _M_omero.api._t_LongList, False, 0),))
    FindPyramidsResponse._ice_type = _M_omero.cmd._t_FindPyramidsResponse

    _M_omero.cmd.FindPyramidsResponse = FindPyramidsResponse
    del FindPyramidsResponse

    _M_omero.cmd.FindPyramidsResponsePrx = FindPyramidsResponsePrx
    del FindPyramidsResponsePrx

if 'OriginalMetadataRequest' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.OriginalMetadataRequest = Ice.createTempClass()
    class OriginalMetadataRequest(_M_omero.cmd.Request):
        """
        Requests the file metadata to be loaded for a given
        image. This should handle both the pre-FS metadata
        in file annotations as well as loading the metadata
        directly from the FS files. A OriginalMetadataResponse
        will be returned under normal conditions, otherwise a ERR
        will be returned.
        """
        def __init__(self, imageId=0):
            _M_omero.cmd.Request.__init__(self)
            self.imageId = imageId

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::OriginalMetadataRequest', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::OriginalMetadataRequest'

        def ice_staticId():
            return '::omero::cmd::OriginalMetadataRequest'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_OriginalMetadataRequest)

        __repr__ = __str__

    _M_omero.cmd.OriginalMetadataRequestPrx = Ice.createTempClass()
    class OriginalMetadataRequestPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.OriginalMetadataRequestPrx.ice_checkedCast(proxy, '::omero::cmd::OriginalMetadataRequest', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.OriginalMetadataRequestPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::OriginalMetadataRequest'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_OriginalMetadataRequestPrx = IcePy.defineProxy('::omero::cmd::OriginalMetadataRequest', OriginalMetadataRequestPrx)

    _M_omero.cmd._t_OriginalMetadataRequest = IcePy.defineClass('::omero::cmd::OriginalMetadataRequest', OriginalMetadataRequest, -1, (), False, False, _M_omero.cmd._t_Request, (), (('imageId', (), IcePy._t_long, False, 0),))
    OriginalMetadataRequest._ice_type = _M_omero.cmd._t_OriginalMetadataRequest

    _M_omero.cmd.OriginalMetadataRequest = OriginalMetadataRequest
    del OriginalMetadataRequest

    _M_omero.cmd.OriginalMetadataRequestPrx = OriginalMetadataRequestPrx
    del OriginalMetadataRequestPrx

if 'OriginalMetadataResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.OriginalMetadataResponse = Ice.createTempClass()
    class OriginalMetadataResponse(_M_omero.cmd.OK):
        """
        Successful response for OriginalMetadataRequest. Contains
        both the global and the series metadata as maps. Only one
        of {@code filesetId} or {@code filesetAnnotationId} will be set.
        Pre-FS images will have {@code filesetAnnotationId} set; otherwise
        {@code filesetId} will be set.
        Members:
        filesetId -- Set to the id of the omero.model.Fileset that this
        omero.model.Image contained in if one exists.
        fileAnnotationId -- Set to the id of the omero.model.FileAnnotation
        linked to this omero.model.Image if one exists.
        globalMetadata -- Metadata which applies to the entire
        omero.model.Fileset
        seriesMetadata -- Metadata specific to the series id of this
        omero.model.Image.
        In the omero.model.Fileset that this
        omero.model.Image is contained in, there may be a large
        number of other images, but the series metadata applies only to
        this specific one.
        """
        def __init__(self, filesetId=None, fileAnnotationId=None, globalMetadata=None, seriesMetadata=None):
            _M_omero.cmd.OK.__init__(self)
            self.filesetId = filesetId
            self.fileAnnotationId = fileAnnotationId
            self.globalMetadata = globalMetadata
            self.seriesMetadata = seriesMetadata

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::OK', '::omero::cmd::OriginalMetadataResponse', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::OriginalMetadataResponse'

        def ice_staticId():
            return '::omero::cmd::OriginalMetadataResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_OriginalMetadataResponse)

        __repr__ = __str__

    _M_omero.cmd.OriginalMetadataResponsePrx = Ice.createTempClass()
    class OriginalMetadataResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.OriginalMetadataResponsePrx.ice_checkedCast(proxy, '::omero::cmd::OriginalMetadataResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.OriginalMetadataResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::OriginalMetadataResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_OriginalMetadataResponsePrx = IcePy.defineProxy('::omero::cmd::OriginalMetadataResponse', OriginalMetadataResponsePrx)

    _M_omero.cmd._t_OriginalMetadataResponse = IcePy.declareClass('::omero::cmd::OriginalMetadataResponse')

    _M_omero.cmd._t_OriginalMetadataResponse = IcePy.defineClass('::omero::cmd::OriginalMetadataResponse', OriginalMetadataResponse, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('filesetId', (), _M_omero._t_RLong, False, 0),
        ('fileAnnotationId', (), _M_omero._t_RLong, False, 0),
        ('globalMetadata', (), _M_omero._t_RTypeDict, False, 0),
        ('seriesMetadata', (), _M_omero._t_RTypeDict, False, 0)
    ))
    OriginalMetadataResponse._ice_type = _M_omero.cmd._t_OriginalMetadataResponse

    _M_omero.cmd.OriginalMetadataResponse = OriginalMetadataResponse
    del OriginalMetadataResponse

    _M_omero.cmd.OriginalMetadataResponsePrx = OriginalMetadataResponsePrx
    del OriginalMetadataResponsePrx

if 'UsedFilesRequest' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.UsedFilesRequest = Ice.createTempClass()
    class UsedFilesRequest(_M_omero.cmd.Request):
        """
        Request to determine the original files associated with the given
        image. The image must have an associated Pixels object. Different
        response objects are returned depending on if the image is FS or
        pre-FS.
        Members:
        imageId -- an image ID
        """
        def __init__(self, imageId=0):
            _M_omero.cmd.Request.__init__(self)
            self.imageId = imageId

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::Request', '::omero::cmd::UsedFilesRequest')

        def ice_id(self, current=None):
            return '::omero::cmd::UsedFilesRequest'

        def ice_staticId():
            return '::omero::cmd::UsedFilesRequest'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_UsedFilesRequest)

        __repr__ = __str__

    _M_omero.cmd.UsedFilesRequestPrx = Ice.createTempClass()
    class UsedFilesRequestPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.UsedFilesRequestPrx.ice_checkedCast(proxy, '::omero::cmd::UsedFilesRequest', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.UsedFilesRequestPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::UsedFilesRequest'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_UsedFilesRequestPrx = IcePy.defineProxy('::omero::cmd::UsedFilesRequest', UsedFilesRequestPrx)

    _M_omero.cmd._t_UsedFilesRequest = IcePy.defineClass('::omero::cmd::UsedFilesRequest', UsedFilesRequest, -1, (), False, False, _M_omero.cmd._t_Request, (), (('imageId', (), IcePy._t_long, False, 0),))
    UsedFilesRequest._ice_type = _M_omero.cmd._t_UsedFilesRequest

    _M_omero.cmd.UsedFilesRequest = UsedFilesRequest
    del UsedFilesRequest

    _M_omero.cmd.UsedFilesRequestPrx = UsedFilesRequestPrx
    del UsedFilesRequestPrx

if 'UsedFilesResponsePreFs' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.UsedFilesResponsePreFs = Ice.createTempClass()
    class UsedFilesResponsePreFs(_M_omero.cmd.OK):
        """
        The used files associated with a pre-FS image.
        Members:
        archivedFiles -- The original file IDs of any archived files associated with
        the image.
        companionFiles -- The original file IDs of any companion files associated with
        the image.
        originalMetadataFiles -- The original file IDs of any original metadata files associated
        with the image.
        """
        def __init__(self, archivedFiles=None, companionFiles=None, originalMetadataFiles=None):
            _M_omero.cmd.OK.__init__(self)
            self.archivedFiles = archivedFiles
            self.companionFiles = companionFiles
            self.originalMetadataFiles = originalMetadataFiles

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::OK', '::omero::cmd::Response', '::omero::cmd::UsedFilesResponsePreFs')

        def ice_id(self, current=None):
            return '::omero::cmd::UsedFilesResponsePreFs'

        def ice_staticId():
            return '::omero::cmd::UsedFilesResponsePreFs'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_UsedFilesResponsePreFs)

        __repr__ = __str__

    _M_omero.cmd.UsedFilesResponsePreFsPrx = Ice.createTempClass()
    class UsedFilesResponsePreFsPrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.UsedFilesResponsePreFsPrx.ice_checkedCast(proxy, '::omero::cmd::UsedFilesResponsePreFs', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.UsedFilesResponsePreFsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::UsedFilesResponsePreFs'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_UsedFilesResponsePreFsPrx = IcePy.defineProxy('::omero::cmd::UsedFilesResponsePreFs', UsedFilesResponsePreFsPrx)

    _M_omero.cmd._t_UsedFilesResponsePreFs = IcePy.defineClass('::omero::cmd::UsedFilesResponsePreFs', UsedFilesResponsePreFs, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('archivedFiles', (), _M_omero.api._t_LongList, False, 0),
        ('companionFiles', (), _M_omero.api._t_LongList, False, 0),
        ('originalMetadataFiles', (), _M_omero.api._t_LongList, False, 0)
    ))
    UsedFilesResponsePreFs._ice_type = _M_omero.cmd._t_UsedFilesResponsePreFs

    _M_omero.cmd.UsedFilesResponsePreFs = UsedFilesResponsePreFs
    del UsedFilesResponsePreFs

    _M_omero.cmd.UsedFilesResponsePreFsPrx = UsedFilesResponsePreFsPrx
    del UsedFilesResponsePreFsPrx

if 'UsedFilesResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.UsedFilesResponse = Ice.createTempClass()
    class UsedFilesResponse(_M_omero.cmd.OK):
        """
        The used files associated with an FS image.
        Members:
        binaryFilesThisSeries -- The original file IDs of any binary files associated with the
        image's particular series.
        binaryFilesOtherSeries -- The original file IDs of any binary files associated with the
        image's fileset but not with its particular series.
        companionFilesThisSeries -- The original file IDs of any companion files associated with the
        image's particular series.
        companionFilesOtherSeries -- The original file IDs of any companion files associated with the
        image's fileset but not with its particular series.
        """
        def __init__(self, binaryFilesThisSeries=None, binaryFilesOtherSeries=None, companionFilesThisSeries=None, companionFilesOtherSeries=None):
            _M_omero.cmd.OK.__init__(self)
            self.binaryFilesThisSeries = binaryFilesThisSeries
            self.binaryFilesOtherSeries = binaryFilesOtherSeries
            self.companionFilesThisSeries = companionFilesThisSeries
            self.companionFilesOtherSeries = companionFilesOtherSeries

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::OK', '::omero::cmd::Response', '::omero::cmd::UsedFilesResponse')

        def ice_id(self, current=None):
            return '::omero::cmd::UsedFilesResponse'

        def ice_staticId():
            return '::omero::cmd::UsedFilesResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_UsedFilesResponse)

        __repr__ = __str__

    _M_omero.cmd.UsedFilesResponsePrx = Ice.createTempClass()
    class UsedFilesResponsePrx(_M_omero.cmd.OKPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.UsedFilesResponsePrx.ice_checkedCast(proxy, '::omero::cmd::UsedFilesResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.UsedFilesResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::UsedFilesResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_UsedFilesResponsePrx = IcePy.defineProxy('::omero::cmd::UsedFilesResponse', UsedFilesResponsePrx)

    _M_omero.cmd._t_UsedFilesResponse = IcePy.defineClass('::omero::cmd::UsedFilesResponse', UsedFilesResponse, -1, (), False, False, _M_omero.cmd._t_OK, (), (
        ('binaryFilesThisSeries', (), _M_omero.api._t_LongList, False, 0),
        ('binaryFilesOtherSeries', (), _M_omero.api._t_LongList, False, 0),
        ('companionFilesThisSeries', (), _M_omero.api._t_LongList, False, 0),
        ('companionFilesOtherSeries', (), _M_omero.api._t_LongList, False, 0)
    ))
    UsedFilesResponse._ice_type = _M_omero.cmd._t_UsedFilesResponse

    _M_omero.cmd.UsedFilesResponse = UsedFilesResponse
    del UsedFilesResponse

    _M_omero.cmd.UsedFilesResponsePrx = UsedFilesResponsePrx
    del UsedFilesResponsePrx

if 'ManageImageBinaries' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.ManageImageBinaries = Ice.createTempClass()
    class ManageImageBinaries(_M_omero.cmd.Request):
        """
        Queries and modifies the various binary artifacts
        which may be linked to an omero.model.Image.
        This can be useful, e.g., after converting pre-OMERO-5
        archived original files into omero.model.Fileset.
        The command works in several stages:
        1. loads an omero.model.Image by id, failing if none
        present.
        2. renames Pixels file to '*_bak'
        3. deletes existing Pyramidfiles if present;
        This command can be run multiple times with different settings
        to iteratively test if the migration is working.
        """
        def __init__(self, imageId=0, togglePixels=False, deletePyramid=False, deleteThumbnails=False):
            _M_omero.cmd.Request.__init__(self)
            self.imageId = imageId
            self.togglePixels = togglePixels
            self.deletePyramid = deletePyramid
            self.deleteThumbnails = deleteThumbnails

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::ManageImageBinaries', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::ManageImageBinaries'

        def ice_staticId():
            return '::omero::cmd::ManageImageBinaries'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_ManageImageBinaries)

        __repr__ = __str__

    _M_omero.cmd.ManageImageBinariesPrx = Ice.createTempClass()
    class ManageImageBinariesPrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.ManageImageBinariesPrx.ice_checkedCast(proxy, '::omero::cmd::ManageImageBinaries', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.ManageImageBinariesPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::ManageImageBinaries'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_ManageImageBinariesPrx = IcePy.defineProxy('::omero::cmd::ManageImageBinaries', ManageImageBinariesPrx)

    _M_omero.cmd._t_ManageImageBinaries = IcePy.defineClass('::omero::cmd::ManageImageBinaries', ManageImageBinaries, -1, (), False, False, _M_omero.cmd._t_Request, (), (
        ('imageId', (), IcePy._t_long, False, 0),
        ('togglePixels', (), IcePy._t_bool, False, 0),
        ('deletePyramid', (), IcePy._t_bool, False, 0),
        ('deleteThumbnails', (), IcePy._t_bool, False, 0)
    ))
    ManageImageBinaries._ice_type = _M_omero.cmd._t_ManageImageBinaries

    _M_omero.cmd.ManageImageBinaries = ManageImageBinaries
    del ManageImageBinaries

    _M_omero.cmd.ManageImageBinariesPrx = ManageImageBinariesPrx
    del ManageImageBinariesPrx

if 'ManageImageBinariesResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.ManageImageBinariesResponse = Ice.createTempClass()
    class ManageImageBinariesResponse(_M_omero.cmd.Response):
        """
        Response from a ManageImageBinaries Request.
        If no action is requested, then the fields of this
        instance can be examined to see what would be done
        if requested.
        """
        def __init__(self, filesetId=None, archivedFiles=None, pixelsPresent=False, pyramidPresent=False, archivedSize=0, pixelSize=0, pyramidSize=0, thumbnailSize=0):
            _M_omero.cmd.Response.__init__(self)
            self.filesetId = filesetId
            self.archivedFiles = archivedFiles
            self.pixelsPresent = pixelsPresent
            self.pyramidPresent = pyramidPresent
            self.archivedSize = archivedSize
            self.pixelSize = pixelSize
            self.pyramidSize = pyramidSize
            self.thumbnailSize = thumbnailSize

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::ManageImageBinariesResponse', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::ManageImageBinariesResponse'

        def ice_staticId():
            return '::omero::cmd::ManageImageBinariesResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_ManageImageBinariesResponse)

        __repr__ = __str__

    _M_omero.cmd.ManageImageBinariesResponsePrx = Ice.createTempClass()
    class ManageImageBinariesResponsePrx(_M_omero.cmd.ResponsePrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.ManageImageBinariesResponsePrx.ice_checkedCast(proxy, '::omero::cmd::ManageImageBinariesResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.ManageImageBinariesResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::ManageImageBinariesResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_ManageImageBinariesResponsePrx = IcePy.defineProxy('::omero::cmd::ManageImageBinariesResponse', ManageImageBinariesResponsePrx)

    _M_omero.cmd._t_ManageImageBinariesResponse = IcePy.declareClass('::omero::cmd::ManageImageBinariesResponse')

    _M_omero.cmd._t_ManageImageBinariesResponse = IcePy.defineClass('::omero::cmd::ManageImageBinariesResponse', ManageImageBinariesResponse, -1, (), False, False, _M_omero.cmd._t_Response, (), (
        ('filesetId', (), _M_omero._t_RLong, False, 0),
        ('archivedFiles', (), _M_omero.api._t_LongList, False, 0),
        ('pixelsPresent', (), IcePy._t_bool, False, 0),
        ('pyramidPresent', (), IcePy._t_bool, False, 0),
        ('archivedSize', (), IcePy._t_long, False, 0),
        ('pixelSize', (), IcePy._t_long, False, 0),
        ('pyramidSize', (), IcePy._t_long, False, 0),
        ('thumbnailSize', (), IcePy._t_long, False, 0)
    ))
    ManageImageBinariesResponse._ice_type = _M_omero.cmd._t_ManageImageBinariesResponse

    _M_omero.cmd.ManageImageBinariesResponse = ManageImageBinariesResponse
    del ManageImageBinariesResponse

    _M_omero.cmd.ManageImageBinariesResponsePrx = ManageImageBinariesResponsePrx
    del ManageImageBinariesResponsePrx

if 'DiskUsage' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.DiskUsage = Ice.createTempClass()
    class DiskUsage(_M_omero.cmd.Request):
        """
        Request to determine the disk usage of the given objects
        and their contents. File-system paths used by multiple objects
        are de-duplicated in the total count. Specifying a class is
        equivalent to specifying all its instances as objects.
        Permissible classes include:
        ExperimenterGroup, Experimenter, Project, Dataset,
        Folder, Screen, Plate, Well, WellSample,
        Image, Pixels, Annotation, Job, Fileset, OriginalFile.
        """
        def __init__(self, classes=None, objects=None):
            _M_omero.cmd.Request.__init__(self)
            self.classes = classes
            self.objects = objects

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::DiskUsage', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::cmd::DiskUsage'

        def ice_staticId():
            return '::omero::cmd::DiskUsage'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_DiskUsage)

        __repr__ = __str__

    _M_omero.cmd.DiskUsagePrx = Ice.createTempClass()
    class DiskUsagePrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DiskUsagePrx.ice_checkedCast(proxy, '::omero::cmd::DiskUsage', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DiskUsagePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::DiskUsage'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DiskUsagePrx = IcePy.defineProxy('::omero::cmd::DiskUsage', DiskUsagePrx)

    _M_omero.cmd._t_DiskUsage = IcePy.defineClass('::omero::cmd::DiskUsage', DiskUsage, -1, (), False, False, _M_omero.cmd._t_Request, (), (
        ('classes', (), _M_omero.api._t_StringSet, False, 0),
        ('objects', (), _M_omero.api._t_StringLongListMap, False, 0)
    ))
    DiskUsage._ice_type = _M_omero.cmd._t_DiskUsage

    _M_omero.cmd.DiskUsage = DiskUsage
    del DiskUsage

    _M_omero.cmd.DiskUsagePrx = DiskUsagePrx
    del DiskUsagePrx

if 'DiskUsageResponse' not in _M_omero.cmd.__dict__:
    _M_omero.cmd.DiskUsageResponse = Ice.createTempClass()
    class DiskUsageResponse(_M_omero.cmd.Response):
        """
        Disk usage report: bytes used and non-empty file counts on the
        repository file-system for specific objects. The counts from the
        maps may sum to more than the total if different types of object
        refer to the same file. Common referrers include:
        Annotation for file annotations
        FilesetEntry for OMERO 5 image files (OMERO.fs)
        Job for import logs
        Pixels for pyramids and OMERO 4 images and archived files
        Thumbnail for the image thumbnails
        The above map values are broken down by owner-group keys.
        """
        def __init__(self, fileCountByReferer=None, bytesUsedByReferer=None, totalFileCount=None, totalBytesUsed=None):
            _M_omero.cmd.Response.__init__(self)
            self.fileCountByReferer = fileCountByReferer
            self.bytesUsedByReferer = bytesUsedByReferer
            self.totalFileCount = totalFileCount
            self.totalBytesUsed = totalBytesUsed

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::cmd::DiskUsageResponse', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::cmd::DiskUsageResponse'

        def ice_staticId():
            return '::omero::cmd::DiskUsageResponse'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.cmd._t_DiskUsageResponse)

        __repr__ = __str__

    _M_omero.cmd.DiskUsageResponsePrx = Ice.createTempClass()
    class DiskUsageResponsePrx(_M_omero.cmd.ResponsePrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.cmd.DiskUsageResponsePrx.ice_checkedCast(proxy, '::omero::cmd::DiskUsageResponse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.cmd.DiskUsageResponsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::cmd::DiskUsageResponse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.cmd._t_DiskUsageResponsePrx = IcePy.defineProxy('::omero::cmd::DiskUsageResponse', DiskUsageResponsePrx)

    _M_omero.cmd._t_DiskUsageResponse = IcePy.defineClass('::omero::cmd::DiskUsageResponse', DiskUsageResponse, -1, (), False, False, _M_omero.cmd._t_Response, (), (
        ('fileCountByReferer', (), _M_omero.api._t_LongPairToStringIntMap, False, 0),
        ('bytesUsedByReferer', (), _M_omero.api._t_LongPairToStringLongMap, False, 0),
        ('totalFileCount', (), _M_omero.api._t_LongPairIntMap, False, 0),
        ('totalBytesUsed', (), _M_omero.api._t_LongPairLongMap, False, 0)
    ))
    DiskUsageResponse._ice_type = _M_omero.cmd._t_DiskUsageResponse

    _M_omero.cmd.DiskUsageResponse = DiskUsageResponse
    del DiskUsageResponse

    _M_omero.cmd.DiskUsageResponsePrx = DiskUsageResponsePrx
    del DiskUsageResponsePrx

# End of module omero.cmd

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ProjectionDef.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')
    _M_omero.model._t_RenderingDefPrx = IcePy.declareProxy('::omero::model::RenderingDef')

if 'ProjectionAxis' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectionAxis = IcePy.declareClass('::omero::model::ProjectionAxis')
    _M_omero.model._t_ProjectionAxisPrx = IcePy.declareProxy('::omero::model::ProjectionAxis')

if 'ProjectionType' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectionType = IcePy.declareClass('::omero::model::ProjectionType')
    _M_omero.model._t_ProjectionTypePrx = IcePy.declareProxy('::omero::model::ProjectionType')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'ProjectionDef' not in _M_omero.model.__dict__:
    _M_omero.model.ProjectionDef = Ice.createTempClass()
    class ProjectionDef(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _renderingDef=None, _axis=None, _type=None, _active=None, _startPlane=None, _endPlane=None, _stepping=None):
            if Ice.getType(self) == _M_omero.model.ProjectionDef:
                raise RuntimeError('omero.model.ProjectionDef is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._renderingDef = _renderingDef
            self._axis = _axis
            self._type = _type
            self._active = _active
            self._startPlane = _startPlane
            self._endPlane = _endPlane
            self._stepping = _stepping

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::ProjectionDef')

        def ice_id(self, current=None):
            return '::omero::model::ProjectionDef'

        def ice_staticId():
            return '::omero::model::ProjectionDef'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getRenderingDef(self, current=None):
            pass

        def setRenderingDef(self, theRenderingDef, current=None):
            pass

        def getAxis(self, current=None):
            pass

        def setAxis(self, theAxis, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getActive(self, current=None):
            pass

        def setActive(self, theActive, current=None):
            pass

        def getStartPlane(self, current=None):
            pass

        def setStartPlane(self, theStartPlane, current=None):
            pass

        def getEndPlane(self, current=None):
            pass

        def setEndPlane(self, theEndPlane, current=None):
            pass

        def getStepping(self, current=None):
            pass

        def setStepping(self, theStepping, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_ProjectionDef)

        __repr__ = __str__

    _M_omero.model.ProjectionDefPrx = Ice.createTempClass()
    class ProjectionDefPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.ProjectionDef._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.ProjectionDef._op_setVersion.end(self, _r)

        def getRenderingDef(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.invoke(self, ((), _ctx))

        def begin_getRenderingDef(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRenderingDef(self, _r):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.end(self, _r)

        def setRenderingDef(self, theRenderingDef, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.invoke(self, ((theRenderingDef, ), _ctx))

        def begin_setRenderingDef(self, theRenderingDef, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.begin(self, ((theRenderingDef, ), _response, _ex, _sent, _ctx))

        def end_setRenderingDef(self, _r):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.end(self, _r)

        def getAxis(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getAxis.invoke(self, ((), _ctx))

        def begin_getAxis(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getAxis.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAxis(self, _r):
            return _M_omero.model.ProjectionDef._op_getAxis.end(self, _r)

        def setAxis(self, theAxis, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setAxis.invoke(self, ((theAxis, ), _ctx))

        def begin_setAxis(self, theAxis, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setAxis.begin(self, ((theAxis, ), _response, _ex, _sent, _ctx))

        def end_setAxis(self, _r):
            return _M_omero.model.ProjectionDef._op_setAxis.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.ProjectionDef._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.ProjectionDef._op_setType.end(self, _r)

        def getActive(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getActive.invoke(self, ((), _ctx))

        def begin_getActive(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getActive.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getActive(self, _r):
            return _M_omero.model.ProjectionDef._op_getActive.end(self, _r)

        def setActive(self, theActive, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setActive.invoke(self, ((theActive, ), _ctx))

        def begin_setActive(self, theActive, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setActive.begin(self, ((theActive, ), _response, _ex, _sent, _ctx))

        def end_setActive(self, _r):
            return _M_omero.model.ProjectionDef._op_setActive.end(self, _r)

        def getStartPlane(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStartPlane.invoke(self, ((), _ctx))

        def begin_getStartPlane(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStartPlane.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStartPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_getStartPlane.end(self, _r)

        def setStartPlane(self, theStartPlane, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStartPlane.invoke(self, ((theStartPlane, ), _ctx))

        def begin_setStartPlane(self, theStartPlane, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStartPlane.begin(self, ((theStartPlane, ), _response, _ex, _sent, _ctx))

        def end_setStartPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_setStartPlane.end(self, _r)

        def getEndPlane(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getEndPlane.invoke(self, ((), _ctx))

        def begin_getEndPlane(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getEndPlane.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEndPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_getEndPlane.end(self, _r)

        def setEndPlane(self, theEndPlane, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setEndPlane.invoke(self, ((theEndPlane, ), _ctx))

        def begin_setEndPlane(self, theEndPlane, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setEndPlane.begin(self, ((theEndPlane, ), _response, _ex, _sent, _ctx))

        def end_setEndPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_setEndPlane.end(self, _r)

        def getStepping(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStepping.invoke(self, ((), _ctx))

        def begin_getStepping(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStepping.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStepping(self, _r):
            return _M_omero.model.ProjectionDef._op_getStepping.end(self, _r)

        def setStepping(self, theStepping, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStepping.invoke(self, ((theStepping, ), _ctx))

        def begin_setStepping(self, theStepping, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStepping.begin(self, ((theStepping, ), _response, _ex, _sent, _ctx))

        def end_setStepping(self, _r):
            return _M_omero.model.ProjectionDef._op_setStepping.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ProjectionDefPrx.ice_checkedCast(proxy, '::omero::model::ProjectionDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ProjectionDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::ProjectionDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ProjectionDefPrx = IcePy.defineProxy('::omero::model::ProjectionDef', ProjectionDefPrx)

    _M_omero.model._t_ProjectionDef = IcePy.declareClass('::omero::model::ProjectionDef')

    _M_omero.model._t_ProjectionDef = IcePy.defineClass('::omero::model::ProjectionDef', ProjectionDef, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_renderingDef', (), _M_omero.model._t_RenderingDef, False, 0),
        ('_axis', (), _M_omero.model._t_ProjectionAxis, False, 0),
        ('_type', (), _M_omero.model._t_ProjectionType, False, 0),
        ('_active', (), _M_omero._t_RBool, False, 0),
        ('_startPlane', (), _M_omero._t_RInt, False, 0),
        ('_endPlane', (), _M_omero._t_RInt, False, 0),
        ('_stepping', (), _M_omero._t_RInt, False, 0)
    ))
    ProjectionDef._ice_type = _M_omero.model._t_ProjectionDef

    ProjectionDef._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getRenderingDef = IcePy.Operation('getRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingDef, False, 0), ())
    ProjectionDef._op_setRenderingDef = IcePy.Operation('setRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    ProjectionDef._op_getAxis = IcePy.Operation('getAxis', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectionAxis, False, 0), ())
    ProjectionDef._op_setAxis = IcePy.Operation('setAxis', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionAxis, False, 0),), (), None, ())
    ProjectionDef._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectionType, False, 0), ())
    ProjectionDef._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionType, False, 0),), (), None, ())
    ProjectionDef._op_getActive = IcePy.Operation('getActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    ProjectionDef._op_setActive = IcePy.Operation('setActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    ProjectionDef._op_getStartPlane = IcePy.Operation('getStartPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setStartPlane = IcePy.Operation('setStartPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getEndPlane = IcePy.Operation('getEndPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setEndPlane = IcePy.Operation('setEndPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getStepping = IcePy.Operation('getStepping', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setStepping = IcePy.Operation('setStepping', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())

    _M_omero.model.ProjectionDef = ProjectionDef
    del ProjectionDef

    _M_omero.model.ProjectionDefPrx = ProjectionDefPrx
    del ProjectionDefPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Pressure.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_Units_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.model.enums
_M_omero.model.enums = Ice.openModule('omero.model.enums')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Pressure' not in _M_omero.model.__dict__:
    _M_omero.model.Pressure = Ice.createTempClass()
    class Pressure(Ice.Object):
        """
        Unit of Pressure which is used through the model. This is not
        an omero.model.IObject implementation and as such does
        not have an ID value. Instead, the entire object is embedded
        into the containing class, so that the value and unit rows
        can be found on the table itself (e.g. imagingEnvironment.pressure
        and imagingEnvironment.pressureUnit).
        Members:
        value -- PositiveFloat value
        unit -- 
        """
        def __init__(self, _value=0.0, _unit=_M_omero.model.enums.UnitsPressure.YOTTAPASCAL):
            if Ice.getType(self) == _M_omero.model.Pressure:
                raise RuntimeError('omero.model.Pressure is an abstract class')
            self._value = _value
            self._unit = _unit

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Pressure')

        def ice_id(self, current=None):
            return '::omero::model::Pressure'

        def ice_staticId():
            return '::omero::model::Pressure'
        ice_staticId = staticmethod(ice_staticId)

        def getValue(self, current=None):
            """
            Actual value for this unit-based field. The interpretation of
            the value is only possible along with the
            omero.model.enums.UnitsPressure enum.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def setValue(self, value, current=None):
            pass

        def getUnit(self, current=None):
            """
            omero.model.enums.UnitsPressure instance which is an
            omero.model.IObject
            meaning that its ID is sufficient for identifying equality.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def setUnit(self, unit, current=None):
            pass

        def getSymbol(self, current=None):
            """
            Returns the possibly unicode representation of the ""unit""
            value for display.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def copy(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Pressure)

        __repr__ = __str__

    _M_omero.model.PressurePrx = Ice.createTempClass()
    class PressurePrx(Ice.ObjectPrx):

        """
        Actual value for this unit-based field. The interpretation of
        the value is only possible along with the
        omero.model.enums.UnitsPressure enum.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getValue(self, _ctx=None):
            return _M_omero.model.Pressure._op_getValue.invoke(self, ((), _ctx))

        """
        Actual value for this unit-based field. The interpretation of
        the value is only possible along with the
        omero.model.enums.UnitsPressure enum.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_getValue.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Actual value for this unit-based field. The interpretation of
        the value is only possible along with the
        omero.model.enums.UnitsPressure enum.
        Arguments:
        """
        def end_getValue(self, _r):
            return _M_omero.model.Pressure._op_getValue.end(self, _r)

        def setValue(self, value, _ctx=None):
            return _M_omero.model.Pressure._op_setValue.invoke(self, ((value, ), _ctx))

        def begin_setValue(self, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_setValue.begin(self, ((value, ), _response, _ex, _sent, _ctx))

        def end_setValue(self, _r):
            return _M_omero.model.Pressure._op_setValue.end(self, _r)

        """
        omero.model.enums.UnitsPressure instance which is an
        omero.model.IObject
        meaning that its ID is sufficient for identifying equality.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getUnit(self, _ctx=None):
            return _M_omero.model.Pressure._op_getUnit.invoke(self, ((), _ctx))

        """
        omero.model.enums.UnitsPressure instance which is an
        omero.model.IObject
        meaning that its ID is sufficient for identifying equality.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getUnit(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_getUnit.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        omero.model.enums.UnitsPressure instance which is an
        omero.model.IObject
        meaning that its ID is sufficient for identifying equality.
        Arguments:
        """
        def end_getUnit(self, _r):
            return _M_omero.model.Pressure._op_getUnit.end(self, _r)

        def setUnit(self, unit, _ctx=None):
            return _M_omero.model.Pressure._op_setUnit.invoke(self, ((unit, ), _ctx))

        def begin_setUnit(self, unit, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_setUnit.begin(self, ((unit, ), _response, _ex, _sent, _ctx))

        def end_setUnit(self, _r):
            return _M_omero.model.Pressure._op_setUnit.end(self, _r)

        """
        Returns the possibly unicode representation of the ""unit""
        value for display.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getSymbol(self, _ctx=None):
            return _M_omero.model.Pressure._op_getSymbol.invoke(self, ((), _ctx))

        """
        Returns the possibly unicode representation of the ""unit""
        value for display.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSymbol(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_getSymbol.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the possibly unicode representation of the ""unit""
        value for display.
        Arguments:
        """
        def end_getSymbol(self, _r):
            return _M_omero.model.Pressure._op_getSymbol.end(self, _r)

        def copy(self, _ctx=None):
            return _M_omero.model.Pressure._op_copy.invoke(self, ((), _ctx))

        def begin_copy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pressure._op_copy.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copy(self, _r):
            return _M_omero.model.Pressure._op_copy.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PressurePrx.ice_checkedCast(proxy, '::omero::model::Pressure', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PressurePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Pressure'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PressurePrx = IcePy.defineProxy('::omero::model::Pressure', PressurePrx)

    _M_omero.model._t_Pressure = IcePy.defineClass('::omero::model::Pressure', Pressure, -1, (), True, False, None, (), (
        ('_value', (), IcePy._t_double, False, 0),
        ('_unit', (), _M_omero.model.enums._t_UnitsPressure, False, 0)
    ))
    Pressure._ice_type = _M_omero.model._t_Pressure

    Pressure._op_getValue = IcePy.Operation('getValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_double, False, 0), ())
    Pressure._op_setValue = IcePy.Operation('setValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_double, False, 0),), (), None, ())
    Pressure._op_getUnit = IcePy.Operation('getUnit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model.enums._t_UnitsPressure, False, 0), ())
    Pressure._op_setUnit = IcePy.Operation('setUnit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model.enums._t_UnitsPressure, False, 0),), (), None, ())
    Pressure._op_getSymbol = IcePy.Operation('getSymbol', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_string, False, 0), ())
    Pressure._op_copy = IcePy.Operation('copy', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Pressure, False, 0), ())

    _M_omero.model.Pressure = Pressure
    del Pressure

    _M_omero.model.PressurePrx = PressurePrx
    del PressurePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
